Integrate ltp network tests to runalltests. Signed-Off-By: Subrata Modak <subrata@linux.vnet.ibm.com>.
diff --git a/runalltests.sh b/runalltests.sh
index a64b613..065304d 100755
--- a/runalltests.sh
+++ b/runalltests.sh
@@ -75,9 +75,14 @@
 ## Make sure you have CD inserted in your CD-ROM drive,
 export RUN_STRESS_CD=0
 
 ##Set this to 1 if you wish to runthe CPUHOTPLUG tests
 export RUN_CPU_HOTPLUG=0
 
+##Set this to 1 if you wish to run the LTP-NETWORK tests. Please refer to:
+## http://ltp.cvs.sourceforge.net/viewvc/ltp/ltp/testcases/network/LTP-Network-test_README.pdf
+## for more information on how to run the tests.
+export RUN_LTP_NETWORK_TESTS=0
+
 export LTP_VERSION=`./runltp -e`
 export TEST_START_TIME=`date +"%Y_%b_%d-%Hh_%Mm_%Ss"`
 export HARDWARE_TYPE=$(uname -i)
@@ -259,3 +264,12 @@
 fi
 ## END => Test Series 11                               ##
 
+## The next one i plan to run are the LTP Network tests
+## START => Test Series 12                             ##
+if [ $RUN_LTP_NETWORK_TESTS -eq 1 ]
+then
+(cd $LTPROOT/testscripts/; ./networktests.sh)
+fi
+## END => Test Series 12                               ##
+
+
@@ -75,9 +75,14 @@
 export RUN_STRESS_CD=0
 
-##Set this to 1 if you wish to runthe CPUHOTPLUG tests
+##Set this to 1 if you wish to run the CPUHOTPLUG tests
 export RUN_CPU_HOTPLUG=0
 